@@ -19,17 +19,16 @@ class BaseSQLQueue(object):
     QUERY_DEFAULT_TIMEOUT = 0
     DEFAULT_CONNECTION_SIZE = 10
 
-    def __init__(self, queue_id, pool_size):
+    def __init__(self, queue_id, max_pool_size):
         """
         Class to add different SQL engines to a pool
 
         :param queue_id: [Optional] Queue_ID
-        :param pool_size: [Optional] Pool_Size for SQL engines
+        :param max_pool_size: [Optional] Pool_Size for SQL engines
         """
-
         self.__queue_id = queue_id
-        self.__pool_size = pool_size
-        self.__sql_engine_pool = LifoQueue(maxsize=pool_size)
+        self.__pool_size = max_pool_size
+        self.__sql_engine_pool = LifoQueue(maxsize=max_pool_size)
         self.__sql_engine_pool_lock = Lock()
         self.__disabled_pool = list()
 
@@ -156,17 +155,18 @@ class BaseSQLQueue(object):
         else:
             log.error('Queue Pool %s: Is in disabled state. Please enable', self.__queue_id)
 
-    def close_pool(self):
+    def close_pool(self, enable_log=True):
         """
         Closes all connections, cursors from all SQLEngines stored in sql queue pool and empty pool
         """
 
         with self.__sql_engine_pool_lock:
-            log.debug('Queue Pool %s: Closing SQL Engine pool', self.__queue_id)
+            if enable_log:
+                log.debug('Queue Pool %s: Closing SQL Engine pool', self.__queue_id)
 
             while True:
                 try:
-                    self.__sql_engine_pool.get(block=False).close_connections(False)
+                    self.__sql_engine_pool.get(block=False).close_connections(False, enable_log=enable_log)
                 except Empty:
                     break
 
@@ -207,7 +207,7 @@ class BaseSQLQueue(object):
             log.warning('Queue Pool %s: Is already enabled', self.__queue_id)
 
     def __del__(self):
-        self.close_pool()
+        self.close_pool(enable_log=False)
 
     def __getstate__(self):
         # The pool and lock cannot be pickled
@@ -233,8 +233,7 @@ class CatchSQLQueue(type):
         if 'queue_id' in kwargs.keys():
             _sql_queue_cache_key = kwargs['queue_id']
         else:
-            kwargs['queue_id'] = sum(map(ord, str(os.urandom(100))))
-            _sql_queue_cache_key = kwargs['queue_id']
+            _sql_queue_cache_key = id(cls)
 
         sql = cls._sql_queue_cache.get(_sql_queue_cache_key)
 
@@ -278,11 +277,15 @@ class CatchSQLQueue(type):
 
 
 class SQLQueue(BaseSQLQueue, metaclass=CatchSQLQueue):
-    SQL_POOLSIZE = 10
-
     """
-    Creates a SQLQueue pool that is cached for SQLEngine instance clases
+    Creates a SQLQueue pool that is cached for SQLEngine instance classes
     """
 
-    def __init__(self, queue_id=None, pool_size=SQL_POOLSIZE):
-        super().__init__(queue_id=queue_id, pool_size=pool_size)
+    def __init__(self, queue_id=None, max_pool_size=None):
+        if not queue_id:
+            queue_id = id(self.__class__)
+
+        if not max_pool_size:
+            max_pool_size = 10
+
+        super().__init__(queue_id=queue_id, max_pool_size=max_pool_size)
