@@ -23,9 +23,6 @@ class TBoxBase(object):
         Lets setup SQLQueue, Logging, Main Config, and Local Config
 
         :param script_path: Script/Application filepath (ie __file__)
-        :param pepper_key_fp: (Optional) Filepath to where Pepper key file is located
-        :param logging_path: (Optional) Filepath to place logging files
-        :param max_pool_size: (Optional) SQL max poolsize for connection queue
         """
 
         from . import default_key_dir
@@ -33,11 +30,12 @@ class TBoxBase(object):
         from .data import DataConfig
 
         self.__base_dir = os.path.dirname(script_path)
-        key_ptr_fp = os.path.join(default_key_dir(), "Key.dir")
-        salt_key_fp = os.path.join(default_key_dir(), "Salt.key")
-        pepper_key_fp = os.path.join(default_key_dir(), "Pepper.key")
+        key_dir = default_key_dir()
+        key_ptr_fp = os.path.join(key_dir, "Key.dir")
+        salt_key_fp = os.path.join(key_dir, "Salt.key")
+        pepper_key_fp = os.path.join(key_dir, "Pepper.key")
 
-        if not (os.path.exists(salt_key_fp) and os.path.exists(pepper_key_fp)) or not os.path.exists(key_ptr_fp):
+        if not (os.path.exists(salt_key_fp) and os.path.exists(pepper_key_fp)) and not os.path.exists(key_ptr_fp):
             obj = DefaultKeySetupGUI(self.__base_dir)
 
             if not obj.key_generated:
@@ -121,9 +119,9 @@ class TBoxBase(object):
             self.__pointer = pointer
 
     def __new_pointer(self, pointer=None, old_db_path=None):
-        from .setup_gui import SetupGUI
+        from .setup_gui import MainDatabaseGUI
 
-        obj = SetupGUI(local_db_dir=self.__base_dir, pointer=pointer, main_db_path=old_db_path)
+        obj = MainDatabaseGUI(local_db_dir=self.__base_dir, pointer=pointer, main_db_path=old_db_path)
 
         if obj.pointer:
             self.pointer = obj.pointer
